# limix-core

[![PyPI-License](https://img.shields.io/pypi/l/limix_core.svg?style=flat-square)](https://pypi.python.org/pypi/limix_core/) [![PyPI-Version](https://img.shields.io/pypi/v/limix_core.svg?style=flat-square)](https://pypi.python.org/pypi/limix_core/)
[![Documentation Status](https://readthedocs.org/projects/limix-core/badge/?style=flat-square&version=1.0.x)](https://limix-core.readthedocs.io/)

Fast inference for Linear Mixed Models and Gaussian Proccesses.
Together with [glimix-core](https://github.com/limix/glimix-core/) it
implements a flexible framework for Linear Mixed Model inference.

See also: https://github.com/limix/limix/

## Install

The recommended way of installing it is via
[pip](https://pypi.python.org/pypi/pip)
```bash
pip install limix-core
```

## Usage

Please, refer to the [documentation](https://limix-core.readthedocs.org).

## Problems

If you encounter any issue, please, [report it](https://github.com/limix/limix-core/issues/new).

## Authors

* **Christoph Lippert** - [https://github.com/clippert](https://github.com/clippert)
* **Danilo Horta** - [https://github.com/Horta](https://github.com/Horta)
* **Franceso Paolo Casale** - [https://github.com/fpcasale](https://github.com/fpcasale)
* **Oliver Stegle** - [https://github.com/ostegle](https://github.com/ostegle)

## License

This project is licensed under the Apache License (Version 2.0, January 2004) -
see the [LICENSE](LICENSE) file for details
